snowballstemmer: Stemmer algorithms for natural language processing in Python
=============================================================================

Description
-----------

This package provides 16 stemmer algorithms (15 + Poerter English
stemmer) generated from Snowball algorithms.

It includes following language algorithms:

-  Danish
-  Dutch
-  English (Standard, Porter)
-  Finnish
-  French
-  German
-  Hungarian
-  Italian
-  Norwegian
-  Portuguese
-  Romanian
-  Russian
-  Spanish
-  Swedish
-  Turkish

This is a pure Python stemming library. If PyStemmer is available, this
module uses it to accelerate.
